<?php 

namespace Teknisa\CNC\Controllers;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;

use Teknisa\CNC\Utilities;
use Teknisa\Libs\Util\Environment;

use Teknisa\CNC\Services\Cnc01300MovimentacaoFinanceiraService;

class Cnc01300MovimentacaoFinanceira {
	protected $util;
	protected $movFinanceiraService;
	protected $environment;
	
	public function __construct(Utilities\Util $util, Cnc01300MovimentacaoFinanceiraService $movFinanceiraService, Environment $environment) {
        $this->util = $util;
        $this->movFinanceiraService = $movFinanceiraService;
        $this->environment = $environment;
	}
	
	public function getAgencias (DTO\Request\Filter $request, DTO\Response $response) {
		try {
			$row = $request->getFilterCriteria()->getConditions();
			$dataSet = $this->movFinanceiraService->getAgencias($row);
			$response->addDataSet(new DataSet('dataSet', $dataSet));
		} catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), $e->getCode()));
		}
	}
	
	public function getContas (DTO\Request\Filter $request, DTO\Response $response) {
		try {
			$row = $request->getFilterCriteria()->getConditions();
			$dataSet = $this->movFinanceiraService->getContas($row);
			$response->addDataSet(new DataSet('dataSet', $dataSet));
		} catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), $e->getCode()));
		}
	}
	
	public function getBancoMasks (DTO\Request\Filter $request, DTO\Response $response) {
	    try {
	        $row = $request->getFilterCriteria()->getConditions();
	        $dataSet = $this->movFinanceiraService->getBancoMasks($row[0]['value']);
	        $response->addDataSet(new DataSet('dataSet', $dataSet));
	    } catch (\Exception $e) {
	        $response->setError(new Error($e->getMessage(), $e->getCode()));
	    }
	}
	
	public function filterMovimentacaoFinanceira (DTO\Request\Filter $request, DTO\Response $response) {
		$allFieldsLabel = 'CDESTABELEC|NMESTABELEC|NMADQUIRENTE|NMPRODUTOADQ|DTCREDITOPREVISTO|DATACREDITO|IDSTATUSLABEL|DSAJUSTE|CDNSU|VRBRUTVENDA|VRLIQPGTO|VRTAXAPREV|VRCOBRADOTAXA|DSMODULO';
		try {
			$row = $request->getFilterCriteria()->getConditions();
			$conditions = $this->util->getParamsAsArray($request);

			$conditions['DTCREDITOINI'] = $conditions['DTCREDITO'][0];
			$conditions['DTCREDITOFIN'] = $conditions['DTCREDITO'][1];
			unset($conditions['DTCREDITO']);

			$this->util->setTCDcondition($conditions, 'CDBANCO');
			$this->util->setTCDcondition($conditions, 'CDAGENCIA');
			$this->util->setTCDcondition($conditions, 'CDCONTCORR');
			$this->util->setTCDcondition($conditions, 'NRPRODUTOADQ');
			$this->util->setTCDcondition($conditions, 'NRADQUIRENTE');
			$this->util->setTCDcondition($conditions, 'NRESTABELEC');
			$this->util->setTCDcondition($conditions, 'IDSTATUSVENDA');
			$this->util->setTCDcondition($conditions, 'CDNSU');
			
			$conditions['CDNSU'] = str_replace('%', '', $conditions['CDNSU']);

			if (!array_key_exists('VRLIQPGTOMIN', $conditions)) {
				$conditions['UVRLIQPGTOMIN']	=	'U';
				$conditions['VRLIQPGTOMIN']		=	null;
			} else {
				$conditions['UVRLIQPGTOMIN']	=	null;
			}
			
			if (!array_key_exists('VRLIQPGTOMAX', $conditions)) {
				$conditions['UVRLIQPGTOMAX']	=	'U';
				$conditions['VRLIQPGTOMAX']		=	null;
			} else {
				$conditions['UVRLIQPGTOMAX']	=	null;
			}

			$this->util->setAllFields($conditions, $allFieldsLabel);
			
			$conditions['NRORG'] =	$this->environment->getNrOrgTrab();
			$dataSet = $this->movFinanceiraService->filterMovimentacaoFinanceira($conditions);
			$response->addDataSet(new DataSet('cnc01300_movimentacao_financeira', $dataSet));
		} catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), $e->getCode()));
		}
	}
	
    public function getProductsOn(DTO\Request\Filter $request, DTO\Response $response){
        try {
            $row = $request->getFilterCriteria()->getConditions();
            $row["LABELPRODUTOADQ"] = isset($row[0]["value"]) ? $row[0]["value"] : "%%";
            $Produto = $this->movFinanceiraService->getProductsOn($row);
            
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('cnc01300_movimentacao_financeira_products', $Produto));
        } catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }

    public function buildParamValue ($arr) {
        return array_reduce($arr, function($accumulator, $element) {
            return $accumulator."|".$element;
        }, "")."|";
    }

}