<?php

namespace Teknisa\CNC\Services;

use Teknisa\CNC\Utilities;
use Teknisa\CNC\Factories;
use Zeedhi\Framework\DB\StoredProcedure\Param;

class Cnc01400CancelamentosAjustes {

	protected $entityManager;
	protected $util;
	protected $cancelAdjustFactory;
	protected $errosPadroes = array(
        '001' => 'Total de crédito difere do total de débito.',
        '002' => 'Data fora do período contábil.',
        '003' => 'Partida %s - Conta contábil não cadastrada.',
        '004' => 'Partida %s - Histórico padrão não cadastrado.',
        '005' => 'Partida %s - Código comercial não cadastrado.',
        '006' => 'Partida %s - Valor da partida zerado.',
        '007' => 'Partida %s - Valor de rateio zerado.',
        '008' => 'Partida %s - Filial de rateio não cadastrada.',
        '009' => 'Partida %s - Centro de custo não cadastrado para filial informada.',
        '010' => 'Partida %s - Soma dos rateios difere do valor da partida.',
        '011' => 'Partida %s - Conta contábil sem código comercial informado.',
        '012' => 'Partida %s - Conta Contábil Gerencial sem rateio informado.',
        '013' => 'Partida %s - Centro de custo deve ser informado.',
        '014' => 'Produto %s sem conta contábil.',
        '015' => 'Lançamento fora do período contábil para o financeiro. (BCO, PAG e REC)',
        '016' => 'Lançamento fora do período contábil de documentos fiscais de entrada. (DFE)',
        '017' => 'Lançamento fora do período contábil para documentos fiscais de saída. (DFS)'
    );

	public function __construct(\Doctrine\ORM\EntityManager $entityManager, Utilities\UtilCNC $util, Factories\Cnc01400CancelamentosAjustesFactory $cancelAdjustFactory)  {
		$this->entityManager = $entityManager;
		$this->util          = $util;
		$this->cancelAdjustFactory  = $cancelAdjustFactory;
	}

    private function isValidDateRangeFilter($filter) {
        return is_array($filter['value']) && sizeof($filter['value']) === 2;
    }

    private function isEmptyOrBlank($obj, $key) {
        return !isset($obj[$key]) || !$obj[$key];
    }

    private function setDefaultQueryValues(&$obj, $keys, $defaultValue) {
        foreach($keys as $key) {
            $obj[$key] = isset($obj[$key]) ? $obj[$key] : $defaultValue;
            if($obj[$key] === null) {
                $obj['T'.$key] = 'T';
            }
        }
    }

    private function bindQueryWithArrayParam($paramName, $paramValue, $query) {
        $valueToBind = !is_array($paramValue) || empty($paramValue) ? 'NULL' : implode(',', $paramValue);
        $newQuery = preg_replace('/'.$paramName.'/', $valueToBind, $query, 4);
        return $newQuery;
    }

	public function getCancelAdjustments($params) {
        $choosenOne = $this->util->getParamFromConditions($params, 'NRESTABELEC');

        if(!isset($choosenOne)){
            $filter = [];
            $mappedFilterNames = [
                'LABELESTABELEC' => 'NRESTABELEC',
                'NMADQUIRENTE'   => 'NRADQUIRENTE',
                'NMPRODUTOADQ'   => 'NRPRODUTOADQ'
            ];
            $likeAll = [];
            foreach($params as $condition) {
                $name = $condition['columnName'];
                $value = $condition['value'];
                $operator = $condition['operator'];
                switch($name) {
                    case 'DTCREDITO':
                    case 'DTVENDA':
                        if($this->isValidDateRangeFilter($condition)) {
                            list($startDate, $endDate) = $value;
                            $newStartDate = str_replace('%', '', $startDate);
                            $newEndDate = str_replace('%', '', $endDate);
                            $filter[$name.'INI'] = $newStartDate ? $newStartDate : null;
                            $filter[$name.'FIN'] = $newEndDate ? $newEndDate : null;
                        }
                        break;
                    default:
                        if($operator === 'MAPPED_LIKE_ALL') {
                            $likeAll = [
                                'name' => implode("||'_'||", explode('|', $name)),
                                'value' => $value[0]['_ALL']
                            ];
                        } else {
                            $nameToSet = isset($mappedFilterNames[$name]) ? $mappedFilterNames[$name] : $name;
                            $selectAll = in_array($value, ['Todas', 'Todos']);
                            $filter[$nameToSet] = $selectAll ? null : $value;
                            $filter['T'.$nameToSet] = $selectAll || $value === null ? 'T' : null;
                        }
                        break;
                }
            }
            $isEmptyDtVendaIni = $this->isEmptyOrBlank($filter, 'DTVENDAINI');
            $isEmptyDtCreditoIni = $this->isEmptyOrBlank($filter, 'DTCREDITOINI');
            if($isEmptyDtVendaIni && $isEmptyDtCreditoIni){
                throw new \Exception('DTVENDCREDERROR',1);
            }
            if($isEmptyDtVendaIni) {
                $filter['TDTVENDA'] = 'T';
            }
            if($isEmptyDtCreditoIni) {
                $filter['TDTCREDITO'] = 'T';
            }
            
            $this->setDefaultQueryValues($filter, [
                'NRADQUIRENTE',
                'NRESTABELEC',
                'NRPRODUTOADQ',
                'DTVENDAINI',
                'DTVENDAFIN',
                'DTCREDITOINI',
                'DTCREDITOFIN',
                'TNRESTABELEC',
                'TNRADQUIRENTE',
                'TNRPRODUTOADQ',
                'TDTVENDA',
                'TDTCREDITO'
            ], null);
            
            $query = $this->cancelAdjustFactory->getQueryCancelAdjustments();
            $query = empty($likeAll) ? $query : "SELECT * FROM ($query) WHERE (". $likeAll['name']. " LIKE '". $likeAll['value'] ."')";
            if(is_array($filter['NRADQUIRENTE']) || is_array($filter['NRPRODUTOADQ']) || is_array($filter['NRESTABELEC'])){
                $query = $this->bindQueryWithArrayParam(':P_NRADQUIRENTE', $filter['NRADQUIRENTE'], $query);
                $query = $this->bindQueryWithArrayParam(':P_NRPRODUTOADQ', $filter['NRPRODUTOADQ'], $query);
                $query = $this->bindQueryWithArrayParam(':P_NRESTABELEC', $filter['NRESTABELEC'], $query);
                $parameters = array(
                    ':P_TNRADQUIRENTE' => $filter['TNRADQUIRENTE'],
                    ':P_TNRPRODUTOADQ' => $filter['TNRPRODUTOADQ'],
                    ':P_TNRESTABELEC'  => $filter['TNRESTABELEC'],
                    ':DTVENDAINI'      => $filter['DTVENDAINI'],
                    ':DTVENDAFIN'      => $filter['DTVENDAFIN'],
                    ':DTCREDITOINI'    => $filter['DTCREDITOINI'],
                    ':DTCREDITOFIN'    => $filter['DTCREDITOFIN'],
                    ':P_TDTVENDA'      => $filter['TDTVENDA'],
                    ':P_TDTCREDITO'    => $filter['TDTCREDITO'],
                    ':P_IDCONCILIADO'  => $filter['IDCONCILIADO']
                ); 
                $CancelAjust = $this->cancelAdjustFactory->getCancelAdjustmentsFiltered($parameters, $query);
    			return $CancelAjust;
    		} else{
    			$parameters = array(
                    ':P_NRADQUIRENTE'   => $filter['NRADQUIRENTE'],
                    ':P_TNRADQUIRENTE'  => $filter['TNRADQUIRENTE'],
                    ':P_NRPRODUTOADQ'   => $filter['NRPRODUTOADQ'],
                    ':P_TNRPRODUTOADQ'  => $filter['TNRPRODUTOADQ'],
                    ':P_NRESTABELEC'    => $filter['NRESTABELEC'],
                    ':P_TNRESTABELEC'   => $filter['TNRESTABELEC'],
                    ':DTVENDAINI'       => $filter['DTVENDAINI'],
                    ':DTVENDAFIN'       => $filter['DTVENDAFIN'],
                    ':DTCREDITOINI'     => $filter['DTCREDITOINI'],
                    ':DTCREDITOFIN'     => $filter['DTCREDITOFIN'],
                    ':P_TDTVENDA'       => $filter['TDTVENDA'],
                    ':P_TDTCREDITO'     => $filter['TDTCREDITO'],
                    ':P_IDCONCILIADO'   => $filter['IDCONCILIADO']
            	);
                $CancelamentoAjuste = $this->cancelAdjustFactory->getCancelAdjustmentsFiltered($parameters, $query);
                return $CancelamentoAjuste;
            } 
        }
        throw new \Exception('DTVENDCREDERROR',1);
	}
	
	public function changeSituationAdjustments($params) {
        $connection = $this->entityManager->getConnection();
        try{
            
            $NRESTABELEC    = $params[0]["NRESTABELEC"];
    	    $NRADQUIRENTE   = $params[0]["NRADQUIRENTE"];
    	    $NMADQUIRENTE   = $params[0]["NMADQUIRENTE"];
    	    $NRPRODUTOADQ   = $params[0]["NRPRODUTOADQ"];
    	    $NRRETFINANCADQ = $params[0]["NRRETFINANCADQ"];
            $IDCONCILIADO   = $params[0]["IDCONCILIADO"];
            $IDSITUACAO     = $params[0]["IDSITUACAO"];
            $IDDEBCRED      = $params[0]["IDDEBCRED"];
            $DESCMOVBANC    = $params[0]["DESCMOVBANC"];
            $DESCMOV        = $params[0]["DESCMOV"];
            $CDNSU          = $params[0]["CDNSU"];
            $EST_NRORG      = $params[0]["NRORG"];
            $DTVENDA        = $params[0]["DTVENDA"];
            $DTCREDITO      = $params[0]["DTCREDITO"];
            $CDFILIAL       = $params[0]["CDFILIAL"];
            $CDCLASSFINA    = $params[0]["CDCLASSFINA"];
            $CDTPCREDBANC   = $params[0]["CDTPCREDBANC"];
            $VRLIQPGTO      = $params[0]["VRLIQPGTO"];
            $CDEMPRESA      = $params[0]["CDEMPRESA"];
            $IDCTBLCRBANC   = $params[0]["IDCTBLCRBANC"];
            $IDCTBLDBBANC   = $params[0]["IDCTBLDBBANC"];
            $NRMOVBANC      = $params[0]["NRMOVBANC"];
            $CDREDUCONT     = $params[0]["CDREDUCONT"];
            $CDTPDBDEBGER   = $params[0]["CDTPDBDEBGER"];
            $IDSTATUSVENDA  = $params[0]["IDSTATUSVENDA"];
            
            $infoFinancAdq   = $this->cancelAdjustFactory->checkFinancAdq(array( 
                ':NRADQUIRENTE'     =>      $NRADQUIRENTE
            ));
            
            $IDGERAFINANC = $infoFinancAdq['IDGERAFINANC'];
            $CDTPDBDEBGER = $infoFinancAdq['CDTPDBDEBGER'];
            $CDTPCREDBANCGER = $infoFinancAdq['CDTPCREDBANCGER'];
            
            $infoRetFinanc = $this->cancelAdjustFactory->checkInfoRetfinanc(array(
                ':NRRETFINANCADQ'   =>      $NRRETFINANCADQ
            ));
            $IDCONCILIADO  = $infoRetFinanc['IDCONCILIADO'];
            $IDSITUACAO    = $infoRetFinanc['IDSITUACAO'];
            $IDSTATUSVENDA = $infoRetFinanc['IDSTATUSVENDA'];

            if($VRLIQPGTO < 0){
                if($IDSTATUSVENDA == 'C'){
                    $CDCLASSFINA = $this->cancelAdjustFactory->checkCDCLASSFINACancelamento(array(
                        ':P_NRESTABELEC'    =>  $NRESTABELEC,
                        ':P_NRADQUIRENTE'   =>  $NRADQUIRENTE,
                        ':P_NRPRODUTOADQ'   =>  $NRPRODUTOADQ,
                        ':P_TIPOPARAM'      =>  'TIPODEB',
                        ':P_GRAVAERRO'      =>  NULL,
                        ':P_DTINICIAL'      =>  NULL,
                        ':P_DTFINAL'        =>  NULL
                    ))['CDCLASSFINA'];
                }else{
                    $CDCLASSFINA = $this->cancelAdjustFactory->checkCDCLASSFINADebito(array(
                        ':NRRETFINANCADQ' => $NRRETFINANCADQ
                    ))['CDCLASSFINA'];
                    
                    $IDCTBLDBBANC = $this->cancelAdjustFactory->checkCDCLASSFINADebito(array(
                        ':NRRETFINANCADQ' => $NRRETFINANCADQ
                    ))['IDCTBLDBBANC'];
                }
            }else{
                $CDCLASSFINA = $this->cancelAdjustFactory->checkCDCLASSFINACredito(array(
                    ':NRRETFINANCADQ' => $NRRETFINANCADQ
                ))['CDCLASSFINA'];    
                
                $IDCTBLCRBANC = $this->cancelAdjustFactory->checkCDCLASSFINACredito(array(
                    ':NRRETFINANCADQ' => $NRRETFINANCADQ
                ))['IDCTBLCRBANC'];    
            }
            
		    switch ($IDSTATUSVENDA) {
		        case "P":
                    $DESCMOV = 'TAXAS DE ADQUIRENTE';
                    $DESCMOVBANC = 'AjusteNegativoAdquirente';
                    $IDDEBCRED = 'D';
                    break;
                case "C":
                    $DESCMOV = 'CANCELAMENTO DE VENDA';
                    $DESCMOVBANC = 'CancVenda';
                    $IDDEBCRED = 'D';
                    break;
                default:
                    $DESCMOV = 'AJUSTE POSITIVO DE ADQUIRENTE';
                    $DESCMOVBANC = 'AjustePositivoAdquirente';
                    $IDDEBCRED = 'C';
            }
            
            $paramsCnc = $this->cancelAdjustFactory->searchParamsCnc(array(
                ':NRESTABELEC'      => $NRESTABELEC,
                ':NRADQUIRENTE'     => $NRADQUIRENTE,
                ':NRPRODUTOADQ'     => $NRPRODUTOADQ
                ));
            
            $CDREDUCONT = $paramsCnc['CDREDUCONT'];
            $CDTPCREDBANC = $paramsCnc['CDTPCREDBANC']; 
                
            if($IDGERAFINANC == 'S'){
        	    if($IDCONCILIADO == "Sim"){
        	        $IDCONCILIADO = 'P';
        	        $IDSITUACAO   = 'N';
        	        $paramsdateAdj = array(
                        ':NRRETFINANCADQ'  => $NRRETFINANCADQ
                    );
                    $paramsTpBanc = array(
                        ':NRADQUIRENTE' => $NRADQUIRENTE
                    );
                    
                    $verifyCdTpBanc = $this->cancelAdjustFactory->getCdTpBancs($paramsTpBanc);
                    $paramIdDebBanc = array(
                        ':CDTPDEBIBANC' => $verifyCdTpBanc[0]['CDTPDBDEBGER']
                    );
                    
                    $paramIdCredBanc = array(
                        ':CDTPCREDBANC' => $verifyCdTpBanc[0]['CDTPCREDBANCGER']      
                    );
    
                    $verifyDebBanc = $this->cancelAdjustFactory->getIdDebBanc($paramIdDebBanc)[0]["IDCTBLDBBANC"];
                    $verifyCredBanc = $this->cancelAdjustFactory->getIdCredBanc($paramIdCredBanc)[0]["IDCTBLCRBANC"];
                    if($IDDEBCRED == 'D'){
                        if(($verifyDebBanc == 'S')){
                            $resultdateAdj = $this->cancelAdjustFactory->validateAdjustmentDate($paramsdateAdj);
                            if (count($resultdateAdj) == 0){
                                    $message = 'Operação Bloqueada! '.$this->errosPadroes["002"];
                                    throw new \Exception('ERR/'.$message, 10);
                            }
                        }
                        
                        $paramsMovBanc = array(
                            ':NRMOVBANC'  => $NRMOVBANC,
                            ':CDREDUCONT' => $CDREDUCONT
                        );

        	            $this->refreshCashFlow($CDEMPRESA, $CDFILIAL, $DTCREDITO, $CDCLASSFINA, $VRLIQPGTO, 'C');
                        $this->refreshBankBalance($CDREDUCONT, $DTCREDITO, $VRLIQPGTO, 'C');
                        $this->cancelAdjustFactory->lancDeb($paramsMovBanc);
                        $this->cancelAdjustFactory->movDebBanc($paramsMovBanc);
        	        
                    }else{
                        if(($verifyCredBanc == 'S')){
                            $resultdateAdj = $this->cancelAdjustFactory->validateAdjustmentDate($paramsdateAdj);
                            if (count($resultdateAdj) == 0){
                                    $message = 'Operação Bloqueada! '.$this->errosPadroes["002"];
                                    throw new \Exception('ERR/'.$message, 10);
                            }
                        }
                        $paramsMovBanc = array(
                            ':NRMOVBANC'  => $NRMOVBANC,
                            ':CDREDUCONT' => $CDREDUCONT
                        );

        	            $this->refreshCashFlow($CDEMPRESA, $CDFILIAL, $DTCREDITO, $CDCLASSFINA, $VRLIQPGTO, 'D');
                        $this->refreshBankBalance($CDREDUCONT, $DTCREDITO, $VRLIQPGTO, 'D');
                        $this->cancelAdjustFactory->lancCred($paramsMovBanc);
                        $this->cancelAdjustFactory->movCredBanc($paramsMovBanc);
            	         
                    }
        	        $this->cancelAdjustFactory->clearBankMoveRet($paramsdateAdj);
                    $this->cancelAdjustFactory->clearBankMove($paramsMovBanc);
                } else{
        	        $IDCONCILIADO = 'C';
        	        $IDSITUACAO   = 'C';
        	        $paramsBankadq = array(
                        ':NRESTABELEC'  => $NRESTABELEC,
                        ':NRADQUIRENTE' => $NRADQUIRENTE,
                        ':NRPRODUTOADQ' => $NRPRODUTOADQ
                    );
        	        $resultBank = $this->cancelAdjustFactory->validateBankFinestadq($paramsBankadq);
                    $resultBank[0]["CDREDUCONT"]      = isset($resultBank[0]["CDREDUCONT"]) ? $resultBank[0]["CDREDUCONT"] : $CDREDUCONT;
                    $resultBank[0]["CDTPDBDEBGER"]    = isset($resultBank[0]["CDTPDBDEBGER"]) ? $resultBank[0]["CDTPDBDEBGER"] : $CDTPDBDEBGER;
                    $resultBank[0]["CDTPCREDBANC"]    = isset($resultBank[0]["CDTPCREDBANC"]) ? $resultBank[0]["CDTPCREDBANC"] : $CDTPCREDBANC;
                    $resultBank[0]["IDCTBLCRBANC"]    = isset($resultBank[0]["IDCTBLCRBANC"]) ? $resultBank[0]["IDCTBLCRBANC"] : $IDCTBLCRBANC;
                    $resultBank[0]["IDCTBLDBBANC"]    = isset($resultBank[0]["IDCTBLDBBANC"]) ? $resultBank[0]["IDCTBLDBBANC"] : $IDCTBLDBBANC;
                    $resultBank[0]["CDTPDEBIBANC"]    = isset($resultBank[0]["CDTPDEBIBANC"]);
                    $resultBank[0]["CDTPCREDBANCGER"] = isset($resultBank[0]["CDTPCREDBANCGER"]) ? $resultBank[0]["CDTPCREDBANCGER"] : $CDTPCREDBANCGER;
                    
                    if ($resultBank[0]["CDREDUCONT"] == null)
                            throw new \Exception('ERR/'.'Operação Bloqueada! Não foi possível realizar a conciliação devido à falta de parametrização da Conta Corrente para a Adquirente '.$NMADQUIRENTE.'.', 1);
                    if($VRLIQPGTO < 0){
                        if ($resultBank[0]["CDTPDBDEBGER"] == null)
                            throw new \Exception('ERR/'.'Operação Bloqueada! Não foi possível realizar a conciliação devido à falta de Tipo de Débito (Genérico) parametrizado para a Adquirente '.$NMADQUIRENTE.'.', 2);
                        if ($resultBank[0]["CDTPDEBIBANC"] == null && $IDSTATUSVENDA == 'C')
                            throw new \Exception('ERR/'.'Operação Bloqueada! Não foi possível realizar a conciliação devido à falta de Tipo de Débito (Cancelamento) parametrizado para a Adquirente '.$NMADQUIRENTE.'.', 2);
                    }else{
                        if ($resultBank[0]["CDTPCREDBANCGER"] == null)
                            throw new \Exception('ERR/'.'Operação Bloqueada! Não foi possível realizar a conciliação devido à falta de Tipo de Crédito (Genérico) parametrizado para a Adquirente '.$NMADQUIRENTE.'.', 2);
                        if ($resultBank[0]["CDTPCREDBANC"] == null)
                            throw new \Exception('ERR/'.'Operação Bloqueada! Não foi possível realizar a conciliação devido à falta de Tipo de Crédito parametrizado para a Adquirente'.$NMADQUIRENTE.'.', 8);
                    }
                    $paramsdateAdj = array(
                        ':NRRETFINANCADQ'  => $NRRETFINANCADQ
                    );
                    $paramsTpBanc = array(
                        ':NRADQUIRENTE' => $NRADQUIRENTE
                    );
                    $verifyCdTpBanc = $this->cancelAdjustFactory->getCdTpBancs($paramsTpBanc);
                    $paramIdDebBanc = array(
                        ':CDTPDEBIBANC' => $verifyCdTpBanc[0]['CDTPDBDEBGER']
                    );
                    $paramIdCredBanc = array(
                        ':CDTPCREDBANC' => $verifyCdTpBanc[0]['CDTPCREDBANCGER']      
                    );
                    $verifyDebBanc = $this->cancelAdjustFactory->getIdDebBanc($paramIdDebBanc)[0]["IDCTBLDBBANC"];
                    $verifyCredBanc = $this->cancelAdjustFactory->getIdCredBanc($paramIdCredBanc)[0]["IDCTBLCRBANC"];
                    
                    if($IDDEBCRED == 'D'){
                        if(($verifyDebBanc == 'S')){
                            $resultdateAdj = $this->cancelAdjustFactory->validateAdjustmentDate($paramsdateAdj);
                            if (count($resultdateAdj) == 0){
                                    $message = 'Operação Bloqueada! '.$this->errosPadroes["002"];
                                    throw new \Exception('ERR/'.$message, 3);
                            }
                        }
                    }else{                        
                        if(($verifyCredBanc == 'S')){
                            $resultdateAdj = $this->cancelAdjustFactory->validateAdjustmentDate($paramsdateAdj);
                            if (count($resultdateAdj) == 0){
                                    $message = 'Operação Bloqueada! '.$this->errosPadroes["002"];
                                    throw new \Exception('ERR/'.$message, 10);
                            }
                        }
                    }
                    if($IDSTATUSVENDA == 'C' || $CDNSU != null){
                        $paramscontNtFsc = array(
                            ':CDNSU'         => $CDNSU,
                            ':DTVENDA'       => $DTVENDA,
                            ':NRADQUIRENTE'  => $NRADQUIRENTE
                        );
                        $resultcontNtFsc = $this->cancelAdjustFactory->validateContNotaFiscal($paramscontNtFsc);
                        if(isset($resultcontNtFsc[0]["CDFILIAL"]) || isset($resultcontNtFsc[0]["NRLANCTONF"])){
                            if($resultcontNtFsc[0]["CDFILIAL"] != null || $resultcontNtFsc[0]["NRLANCTONF"] != null){
                                $paramsdelContNtFsc = array(
                                    ':CDFILIAL'   => $resultcontNtFsc[0]["CDFILIAL"],
                                    ':NRLANCTONF' => $resultcontNtFsc[0]["NRLANCTONF"]
                                );
                                $this->cancelAdjustFactory->deleteContNotaFiscal($paramsdelContNtFsc);
                            }
                        }
                    }
                    $NRMOVBANC = $this->util->newCodeNT('MOVBANCARIO'.$resultBank[0]["CDREDUCONT"], '10');
                    $paramsbankmove = array(
                        ':CDREDUCONT'  => $resultBank[0]["CDREDUCONT"],
                        ':NRMOVBANC'   => $NRMOVBANC,
                        ':DTCREDITO'   => $DTCREDITO,
                        ':IDDEBCRED'   => $IDDEBCRED,
                        ':DESCMOVBANC' => $DESCMOVBANC,
                        ':VRLIQPGTO'   => $VRLIQPGTO,
                        ':EST_NRORG'   => $EST_NRORG,
                        ':CDNSU'       => $CDNSU
                    );
                    $this->cancelAdjustFactory->changeBankMove($paramsbankmove);
                    $params = array(
                        ':NRRETFINANCADQ' => $NRRETFINANCADQ,
                        ':CDREDUCONT'     => $resultBank[0]["CDREDUCONT"],
                        ':NRMOVBANC'      => $NRMOVBANC
                    );
                    
                    $this->cancelAdjustFactory->changeMovBancAdjustments($params);
                    
                    $paramsBankadq = array(
                        ':NRADQUIRENTE' => $NRADQUIRENTE
                    );
                    $setClient = $this->cancelAdjustFactory->getClient($paramsBankadq);
                    $setClient[0]["CDCLIENTE"] = isset($setClient[0]["CDCLIENTE"]) ? $setClient[0]["CDCLIENTE"] : null;
                    $CDCLIENTE = $setClient[0]["CDCLIENTE"];
                    
                    if($VRLIQPGTO < 0){
                       $this->refreshCashFlow($CDEMPRESA, $CDFILIAL, $DTCREDITO, $CDCLASSFINA, $VRLIQPGTO, 'D');
                       $this->refreshBankBalance($resultBank[0]["CDREDUCONT"], $DTCREDITO, $VRLIQPGTO, 'D');
                       $NRMOVIDEBI = $this->util->newCodeNT('MOVDEBBANC'.$resultBank[0]["CDREDUCONT"], '10');
                       $paramsdebbanc = array(
                        ':CDREDUCONT'  => $resultBank[0]["CDREDUCONT"],
                        ':NRMOVIDEBI'  => $NRMOVIDEBI,
                        ':CDCLASSFINA' => $CDCLASSFINA,
                        ':CDEMPRESA'   => $CDEMPRESA,
                        ':CDFILIAL'    => $CDFILIAL,
                        ':NRMOVBANC'   => $NRMOVBANC,
                        ':CDTPDEBIBANC'=> $resultBank[0]["CDTPDBDEBGER"],
                        ':DTCREDITO'   => $DTCREDITO,
                        ':DESCMOV'     => $DESCMOV,
                        ':VRLIQPGTO'   => $VRLIQPGTO,
                        ':EST_NRORG'   => $EST_NRORG,
                        ':CDCLIENTE'   => $CDCLIENTE,
                        ':CDECTBMDEB'  => $CDEMPRESA
                        
                       );
                       $this->cancelAdjustFactory->changeMoveDebBanc($paramsdebbanc);
                        if($resultBank[0]["IDCTBLDBBANC"] == 'S'){
                            $return = $this->ctbBcoLanc($resultBank[0]["CDREDUCONT"], $NRMOVIDEBI, 'D');
                            $NRLANCCTBTEMP = $return["P_NRLANCCTB"];
                            $paramserrors = array(
                                ':CDEMPRESA'      => $CDEMPRESA,
                                ':NRLANCCTBTEMP'  => $NRLANCCTBTEMP
                            );
                            $errors = $this->cancelAdjustFactory->getErrors($paramserrors);
                            if($errors[0]["QT"] != 0){
                                $error = $this->cancelAdjustFactory->getError($paramserrors);
                                $message = "";
                                foreach ($error as $key => $value) {
                                    if($key > 0){
                                        $message .= '|'.$this->errosPadroes[$error[$key]["CDERROTEMP"]];
                                    } else {
                                        $message .= $this->errosPadroes[$error[$key]["CDERROTEMP"]];
                                    }
                                }
                                throw new \Exception('CTB/'.$CDEMPRESA.'|'.$NRLANCCTBTEMP, 16);
                            }
                        }
                        
                    } else{
                       $this->refreshCashFlow($CDEMPRESA, $CDFILIAL, $DTCREDITO, $CDCLASSFINA, $VRLIQPGTO, 'C');
                       $this->refreshBankBalance($resultBank[0]["CDREDUCONT"], $DTCREDITO, $VRLIQPGTO, 'C');
                       $NRMOVICRED = $this->util->newCodeNT('MOVCREDBANC'.$CDREDUCONT, '10');
                       $paramscredbanc = array(
                        ':CDREDUCONT'  => $resultBank[0]["CDREDUCONT"],
                        ':NRMOVICRED'  => $NRMOVICRED,
                        ':CDCLASSFINA' => $CDCLASSFINA,
                        ':CDEMPRESA'   => $CDEMPRESA,
                        ':CDFILIAL'    => $CDFILIAL,
                        ':NRMOVBANC'   => $NRMOVBANC,
                        ':CDTPCREDBANC'=> $resultBank[0]["CDTPCREDBANC"],
                        ':DTCREDITO'   => $DTCREDITO,
                        ':DESCMOV'     => $DESCMOV,
                        ':VRLIQPGTO'   => $VRLIQPGTO,
                        ':EST_NRORG'   => $EST_NRORG,
                        ':CDCLIENTE'   => $CDCLIENTE,
                        ':CDFILIAL'    => $CDFILIAL,
                        ':CDECTBMCRED' => $CDEMPRESA
                        );
                       $this->cancelAdjustFactory->changeMoveCredBanc($paramscredbanc);
                        if($resultBank[0]["IDCTBLCRBANC"] == 'S'){
                            $return = $this->ctbBcoLanc($resultBank[0]["CDREDUCONT"], $NRMOVICRED, 'C');
                            $NRLANCCTBTEMP = $return["P_NRLANCCTB"];
                            $paramserrors = array(
                                ':CDEMPRESA'      => $CDEMPRESA,
                                ':NRLANCCTBTEMP'  => $NRLANCCTBTEMP
                            );
                            $errors = $this->cancelAdjustFactory->getErrors($paramserrors);
                            if($errors[0]["QT"] != 0){
                                throw new \Exception('CTB/'.$CDEMPRESA.'|'.$NRLANCCTBTEMP, 9);
                            }
                        } 
                    }
            	}
            } else{
                if($IDCONCILIADO == "Sim"){
                    $IDCONCILIADO = 'P';
        	        $IDSITUACAO   = 'N';
                } else{
                    $IDCONCILIADO = 'C';
        	        $IDSITUACAO   = 'C'; 
                }
            }
    
            $params = array(
                ':NRRETFINANCADQ' => $NRRETFINANCADQ,
                ':IDCONCILIADO'   => $IDCONCILIADO,
                ':IDSITUACAO'     => $IDSITUACAO
            );
            $this->cancelAdjustFactory->changeSituationAdjustments($params);
	    } catch (\Exception $e){
	        $paramsdateAdj = array(
                ':NRRETFINANCADQ'  => $NRRETFINANCADQ
            );
            $paramsMovBanc = array(
                ':NRMOVBANC'  => $NRMOVBANC,
                ':CDREDUCONT' => $CDREDUCONT
            );
	        $this->cancelAdjustFactory->clearBankMoveRet($paramsdateAdj);
            $this->cancelAdjustFactory->movDebBanc($paramsMovBanc);
            $this->cancelAdjustFactory->movCredBanc($paramsMovBanc);
	        $this->cancelAdjustFactory->clearBankMove($paramsMovBanc);
	        throw $e;
	    }
    }
    
    public function getErrors($params) {
        $CDEMPRESA	   = $params[0]["value"];
		$NRLANCCTBTEMP = $params[1]["value"];
		$DSERROS       = [];
		$params = array(
			':CDEMPRESA' 		 => $CDEMPRESA,
			':NRLANCCTBTEMP'      => $NRLANCCTBTEMP
		);
		$error = $this->cancelAdjustFactory->getError($params);
		foreach ($error as $key => $value) {
		    $NRSEQCTBTEMP = $error[$key]["NRSEQCTBTEMP"];
		    $DSERRO = $this->errosPadroes[$error[$key]["CDERROTEMP"]];
		    if(strrpos($DSERRO, "%s") !== false){
		        $DSERRO = str_replace('%s', $NRSEQCTBTEMP, $DSERRO);
                $DSERROS[$key]["DSERRO"] = $DSERRO;
            } else {
                $DSERROS[$key]["DSERRO"] = $DSERRO;
            }
		}
		$this->cancelAdjustFactory->deleteErrors($params);
		return $DSERROS;
	}
	
	public function deleteErrors ($params) {
        $CDEMPRESA   = $params[0]['CDEMPRESA'];
		$NRLANCCTBTEMP = $params[0]['NRLANCCTBTEMP'];

		$paramethers = array(
			':CDEMPRESA'   => $CDEMPRESA,
			':NRLANCCTBTEMP' => $NRLANCCTBTEMP
		);

		$this->cancelAdjustFactory->deleteErrors($paramethers);
	}
    
    public function refreshCashFlow($CDEMPRESA, $CDFILIAL, $DTCREDITO, $CDCLASSFINA, $VRLIQPGTO, $TPG){
        $params["P_CDEMPRESA"] = $CDEMPRESA;
        $params["P_CDFILIAL"] = $CDFILIAL;
        $params["P_DTCREDITO"] = $DTCREDITO;
        $params["P_CDCLASSFINA"] = $CDCLASSFINA;
        if($TPG == 'D'){
            $params["P_VRENTMFLUXO"] = 0;
            $params["P_VRSAIMFLUXO"] = abs($VRLIQPGTO);
        }else{
            $params["P_VRENTMFLUXO"] = abs($VRLIQPGTO);
            $params["P_VRSAIMFLUXO"] = 0;
        }
        $this->cancelAdjustFactory->refreshCashFlow($params);
    }
    
    public function refreshBankBalance($CDREDUCONT, $DTCREDITO, $VRLIQPGTO, $TPG){
        $params["P_CDREDUCONT"] = $CDREDUCONT;
        $params["P_DTCREDITO"]  = $DTCREDITO;
        if($TPG == 'D'){
            $params["P_VRSDOCCORR"]  = abs($VRLIQPGTO)*-1;
        }else{
            $params["P_VRSDOCCORR"]  = abs($VRLIQPGTO); 
        }
        $this->cancelAdjustFactory->refreshBankBalance($params);
    }
    
    public function ctbBcoLanc($CDREDUCONT, $NRLANCCTBTEMP, $IDTIPO){
        $params["P_CDREDUCONT"] = $CDREDUCONT;
        $params["P_NRLANCCTBTEMP"]  = $NRLANCCTBTEMP;
        $params["P_IDTIPO"]  = $IDTIPO;
        $result = $this->cancelAdjustFactory->ctbBcoLanc($params);
        return $result; 
    }

}