<?php

namespace Teknisa\CNC\Services;

use Teknisa\CNC\Utilities;
use Teknisa\CNC\Factories;

class VendasCNC {

	protected $entityManager;
	protected $util;
	protected $vendaFactory;

	public function __construct(\Doctrine\ORM\EntityManager $entityManager, Utilities\UtilCNC $util, Factories\VendasCNCFactory $vendaFactory)  {
		$this->entityManager = $entityManager;
		$this->util          = $util;
		$this->vendaFactory  = $vendaFactory;
	}

	public function getNoExistSells($params) {
		$CDCUPOM = null;
		for ($i=0; $i < sizeof($params); $i++) {
            if($params[$i]["columnName"] === 'CDCUPOM'){
                $CDCUPOM = $params[$i]['value'];
            }
        }
        if($CDCUPOM === null){
            $DTVENDAINI = $params[0]['value'][0];
            $DTVENDAFIN = $params[0]['value'][1];
            $CDCUPOM    = "%%";
            $VRVENDAINI = $params[1]['value'];
            $VRVENDAFIN = $params[2]['value'];
            $CDFILIAL   = $params[3]['value'];
        } else{
            $DTVENDAINI = $params[0]['value'][0];
            $DTVENDAFIN = $params[0]['value'][1];
            $VRVENDAINI = $params[2]['value'];
            $VRVENDAFIN = $params[3]['value'];
            $CDFILIAL   = $params[4]['value'];
        }
        if($VRVENDAINI === "%null%" || $VRVENDAFIN === "%null%"){
            if(($VRVENDAINI === "%null%" && !($VRVENDAFIN === "%null%")) || (!($VRVENDAINI === "%null%") && $VRVENDAFIN === "%null%")){
                throw new \Exception('VRVENDANULL',1);
            } else{ 
                $VRVENDAINI = null;
                $VRVENDAFIN = null;
                $P_TVRVENDA = 'T';
            }
        }
        else{
            $VRVENDAINI = $this->util->moneyToDouble($VRVENDAINI);
            $VRVENDAFIN = $this->util->moneyToDouble($VRVENDAFIN);
            $P_TVRVENDA = null;
            if($VRVENDAINI > $VRVENDAFIN){
              throw new \Exception('VRVENDA',2);
            }
        }
        $parameters = array(
            ':CDFILIAL'   => $CDFILIAL,
            ':DTVENDAINI' => $DTVENDAINI,
            ':DTVENDAFIN' => $DTVENDAFIN,
            ':CDCUPOM'    => $CDCUPOM,
            ':VRVENDAINI' => $VRVENDAINI,
            ':VRVENDAFIN' => $VRVENDAFIN,
            ':P_TVRVENDA' => $P_TVRVENDA
        );

        $vendasin = $this->vendaFactory->getNoExistSells($parameters);
		return $vendasin;
	}

	public function getConciliatorSells($params) {
        $NRESTABELEC     = $params[0]['value'];
        $DTVENDAINI      = $params[1]['value'][0];
        $DTVENDAFIN      = $params[1]['value'][1];
        $P_NRSEQADQ      = $params[2]['value'];
        $P_NMPRODADQ     = $params[3]['value'];
        $P_TNRSEQADQ     = null;

        if($P_NRSEQADQ === 'Todas'){
            $P_TNRSEQADQ = 'T';
            $P_NRSEQADQ  = null;
        }
        if(is_array($P_NRSEQADQ)){
            $query = "SELECT NVTOTAL, COUNT(*) NVCONCILIADO FROM (SELECT COUNT(CO.NRCONSMOVCAIXA) OVER (PARTITION BY 1) NVTOTAL, R.NRRETVENDAADQ, R.NRPRODUTOADQ FROM ESTABELECIMENTO E, CONSMOVCAIXA CO LEFT JOIN RETVENDAADQ R JOIN ADQUIRENTE AD ON AD.NRADQUIRENTE = R.NRADQUIRENTE AND ((INSTR (:P_NRSEQADQ, '|'||TO_CHAR(AD.NRADQUIRENTE)||'|') > 0) OR ('T' = :P_TNRSEQADQ)) JOIN PRODUTOADQ PX ON PX.NRPRODUTOADQ = R.NRPRODUTOADQ AND PX.NMPRODUTOADQ = :P_NMPRODADQ ON R.NRCONCLANC = CO.NRCONCLANC AND R.IDCONCILIADO = 'C'JOIN RETVENDAADQ RT JOIN ADQUIRENTE A ON A.NRADQUIRENTE = RT.NRADQUIRENTE AND ((INSTR (:P_NRSEQADQ, '|'||TO_CHAR(A.NRADQUIRENTE)||'|') > 0) OR ('T' = :P_TNRSEQADQ)) JOIN PRODUTOADQ PA ON PA.NRPRODUTOADQ = RT.NRPRODUTOADQ AND PA.NMPRODUTOADQ = :P_NMPRODADQ ON RT.NRCONCLANC = CO.NRCONCLANC WHERE CO.DTVENDA BETWEEN TO_DATE(:DTVENDAINI, 'dd/mm/yy') AND TO_DATE(:DTVENDAFIN, 'dd/mm/yy') AND :NRESTABELEC = E.NRESTABELEC)C JOIN PRODUTOADQ P ON C.NRPRODUTOADQ = P.NRPRODUTOADQ GROUP BY NVTOTAL"; 
            if(is_array($P_NRSEQADQ)){
                $paramsadquirirente = array(
                    ':P_NRSEQADQ' => $P_NRSEQADQ
                );
                foreach (array_keys($paramsadquirirente) as $index => $name) {
                    if(!empty($paramsadquirirente[$name])){
                        $query = $this->util->putArrayOnQuery($query, $name, $paramsadquirirente[$name]);
                        $paramsadquirirente[$name] = '';
                    }
                    else{
                        $paramsadquirirente[$name] = 'null';
                    }
                }
            }
            $parameters = array(
                ':NRESTABELEC'    => $NRESTABELEC,
                ':P_TNRSEQADQ'    => $P_TNRSEQADQ,
                ':P_NMPRODADQ'    => $P_NMPRODADQ,
                ':DTVENDAINI'     => $DTVENDAINI,
                ':DTVENDAFIN'     => $DTVENDAFIN
            );
            $vendascon = $this->vendaFactory->getConciliatorSellsFiltered($parameters, $query);
            return $vendascon;
        } else{
            $parameters = array(
                ':NRESTABELEC'    => $NRESTABELEC,
                ':P_NRSEQADQ'     => $P_NRSEQADQ,
                ':P_TNRSEQADQ'    => $P_TNRSEQADQ,
                ':P_NMPRODADQ'    => $P_NMPRODADQ,
                ':DTVENDAINI'     => $DTVENDAINI,
                ':DTVENDAFIN'     => $DTVENDAFIN
            );
            $VendaConciliada = $this->vendaFactory->getConciliatorSells($parameters);
            return $VendaConciliada;
        } 
    }

    public function getConciliatorSellsDetails($params) {
        $NRESTABELEC     = $params[0]['value'];
        $P_NRSEQADQ      = $params[1]['value'];
        $P_NMPRODADQ     = $params[2]['value'];
        $DTVENDAINI      = $params[3]['value'];
        $DTVENDAFIN      = $params[4]['value'];
        $P_TNRSEQADQ     = null;

        if($P_NRSEQADQ === 'Todas'){
            $P_TNRSEQADQ = 'T';
            $P_NRSEQADQ  = null;
        }
        if(is_array($P_NRSEQADQ)){
            $query = "SELECT R.IDCONCILIADO PRIMARY, '' PARENT, DECODE(R.IDCONCILIADO, 'C', 'Vendas Conciliadas', 'Vendas não Conciliadas') IDCONDICAO, NULL DTORDENACAO, NULL DTVENDA, '' CDNSU, '' CDCUPOM, SUM(R.VRBRUTVENDA) VRBRUTVENDA, NULL NRRETVENDAADQ, NULL NRADQUIRENTE, '' NMADQUIRENTE, NULL NRPRODUTOADQ, '' NMPRODUTOADQ FROM ESTABELECIMENTO E, CONSMOVCAIXA CO LEFT JOIN RETVENDAADQ R JOIN ADQUIRENTE AD ON AD.NRADQUIRENTE = R.NRADQUIRENTE AND ((INSTR (:P_NRSEQADQ, '|'||TO_CHAR(AD.NRADQUIRENTE)||'|') > 0) OR ('T' = :P_TNRSEQADQ)) JOIN PRODUTOADQ PX ON PX.NRPRODUTOADQ = R.NRPRODUTOADQ AND PX.NMPRODUTOADQ = :P_NMPRODADQ ON R.NRCONCLANC = CO.NRCONCLANC AND CO.NRCONCLANC IS NOT NULL JOIN RETVENDAADQ RT JOIN ADQUIRENTE A ON A.NRADQUIRENTE = RT.NRADQUIRENTE AND ((INSTR (:P_NRSEQADQ, '|'||TO_CHAR(A.NRADQUIRENTE)||'|') > 0) OR ('T' = :P_TNRSEQADQ)) JOIN PRODUTOADQ PA ON PA.NRPRODUTOADQ = RT.NRPRODUTOADQ AND PA.NMPRODUTOADQ = :P_NMPRODADQ ON RT.NRCONCLANC = CO.NRCONCLANC WHERE CO.DTVENDA BETWEEN TO_DATE(:DTVENDAINI, 'dd/mm/yy') AND TO_DATE(:DTVENDAFIN, 'dd/mm/yy') AND :NRESTABELEC = E.NRESTABELEC GROUP BY R.IDCONCILIADO, PX.NMPRODUTOADQ UNION SELECT R.IDCONCILIADO || ' - ' || R.NRRETVENDAADQ PRIMARY, R.IDCONCILIADO PARENT, '' IDCONDICAO, R.DTVENDA DTORDENACAO, TO_CHAR(R.DTVENDA, 'DD/MM/YY') DTVENDA, R.CDNSU, CO.CDCUPOM, R.VRBRUTVENDA, R.NRRETVENDAADQ, R.NRADQUIRENTE, AD.NMADQUIRENTE, R.NRPRODUTOADQ, PX.NMPRODUTOADQ FROM ESTABELECIMENTO E, CONSMOVCAIXA CO LEFT JOIN RETVENDAADQ R JOIN ADQUIRENTE AD ON AD.NRADQUIRENTE = R.NRADQUIRENTE AND ((INSTR (:P_NRSEQADQ, '|'||TO_CHAR(AD.NRADQUIRENTE)||'|') > 0) OR ('T' = :P_TNRSEQADQ)) JOIN PRODUTOADQ PX ON PX.NRPRODUTOADQ = R.NRPRODUTOADQ AND (INSTR (:P_NMPRODADQ, PX.NMPRODUTOADQ) > 0) ON R.NRCONCLANC = CO.NRCONCLANC AND CO.NRCONCLANC IS NOT NULL JOIN RETVENDAADQ RT JOIN ADQUIRENTE A ON A.NRADQUIRENTE = RT.NRADQUIRENTE AND ((INSTR (:P_NRSEQADQ, '|'||TO_CHAR(A.NRADQUIRENTE)||'|') > 0) OR ('T' = :P_TNRSEQADQ)) JOIN PRODUTOADQ PA ON PA.NRPRODUTOADQ = RT.NRPRODUTOADQ AND (INSTR (:P_NMPRODADQ, PA.NMPRODUTOADQ) > 0) ON RT.NRCONCLANC = CO.NRCONCLANC WHERE CO.DTVENDA BETWEEN TO_DATE(:DTVENDAINI, 'dd/mm/yy') AND TO_DATE(:DTVENDAFIN, 'dd/mm/yy') AND :NRESTABELEC = E.NRESTABELEC ORDER BY DTORDENACAO, PRIMARY"; 
            if(is_array($P_NRSEQADQ)){
                $paramsadquirirente = array(
                    ':P_NRSEQADQ' => $P_NRSEQADQ
                );
                foreach (array_keys($paramsadquirirente) as $index => $name) {
                    if(!empty($paramsadquirirente[$name])){
                        $query = $this->util->putArrayOnQuery($query, $name, $paramsadquirirente[$name]);
                        $paramsadquirirente[$name] = '';
                    }
                    else{
                        $paramsadquirirente[$name] = 'null';
                    }
                }
            }
            $parameters = array(
                ':NRESTABELEC'    => $NRESTABELEC,
                ':P_TNRSEQADQ'    => $P_TNRSEQADQ,
                ':P_NMPRODADQ'    => $P_NMPRODADQ,
                ':DTVENDAINI'     => $DTVENDAINI,
                ':DTVENDAFIN'     => $DTVENDAFIN
            );
            $vendascon = $this->vendaFactory->getConciliatorSellsDetailsFiltered($parameters, $query);
            return $vendascon;
        } else{
            $parameters = array(
                ':NRESTABELEC'    => $NRESTABELEC,
                ':P_NRSEQADQ'     => $P_NRSEQADQ,
                ':P_TNRSEQADQ'    => $P_TNRSEQADQ,
                ':P_NMPRODADQ'    => $P_NMPRODADQ,
                ':DTVENDAINI'     => $DTVENDAINI,
                ':DTVENDAFIN'     => $DTVENDAFIN
            );
            $VendaConciliada = $this->vendaFactory->getConciliatorSellsDetails($parameters);
            return $VendaConciliada;
        } 
    }

    public function getAnticipatedSells($conditions) {

        $allFieldsName = 'DTCREDITO|NMESTABELEC|NMADQUIRENTE|CDLOTEVENDA|VRBRUTVENDA|VRLIQPGTO|VRTAXAANT';
        $dtlote = $conditions['DTCREDITO'];
        
        if(array_key_exists($allFieldsName, $conditions)) {
            $conditions['ALL_FIELDS'] = $conditions[$allFieldsName][0]['_ALL'];            
            $conditions['ALL_FIELDS'] = str_replace("%", "", $conditions['ALL_FIELDS']);
            $conditions['TALL_FIELDS'] = 'F';
            unset($conditions[$allFieldsName]);
        } else {
            $conditions['ALL_FIELDS'] = '';
            $conditions['TALL_FIELDS'] = 'T';
        }
        
        
        $adquirente = array_key_exists('NRADQUIRENTE', $conditions)
                            ? $conditions['NRADQUIRENTE'] 
                            : null;
        $estabelecimento = array_key_exists('NRESTABELEC', $conditions)
                            ? $conditions['NRESTABELEC'] 
                            : null;
        $produto = array_key_exists('NRPRODUTOADQ', $conditions)
                            ? $conditions['NRPRODUTOADQ'] 
                            : null;

        $P_TNRADQUIRENTE = null;
        $P_TNRPRODUTOADQ = null;
        $P_TNRESTABELEC  = null;

        empty($produto)
            ? $P_NRPRODUTOADQ = 'Todas'
            : $P_NRPRODUTOADQ = $produto;

        empty($estabelecimento)
            ? $P_NRESTABELEC = 'Todas'
            : $P_NRESTABELEC = $estabelecimento;
    
        empty($adquirente)
            ? $P_NRADQUIRENTE = 'Todas'
            : $P_NRADQUIRENTE = $produto;
        
        $P_NRADQUIRENTE = $adquirente;

        if(empty($P_NRESTABELEC) || $P_NRESTABELEC === 'Todas') {
            $P_TNRESTABELEC = 'T';
            $P_NRESTABELEC  = null;
        }
        
        if(empty($P_NRADQUIRENTE) || $P_NRADQUIRENTE  === 'Todas') {
            $P_TNRADQUIRENTE = 'T';
            $P_NRADQUIRENTE  = null;
        }
        
        if(empty($P_NRPRODUTOADQ) || $P_NRPRODUTOADQ === 'Todas') {
            $P_TNRPRODUTOADQ = 'T';
            $P_NRPRODUTOADQ  = null;
        }
        
        if( is_array($P_NRADQUIRENTE) || 
            is_array($P_NRESTABELEC) || 
            is_array($P_NRPRODUTOADQ) ) {
            $query = "SELECT TO_CHAR(R.DTCREDITO, 'dd/mm/yyyy') DTCREDITO, E.CDESTABELEC, L.CDLOTEVENDA, E.NMESTABELEC, A.NMADQUIRENTE, SUM(R.VRBRUTVENDA) VRBRUTVENDA, 
                SUM(R.VRLIQPGTO) VRLIQPGTO, R.VRTAXAANT, A.NRADQUIRENTE, E.NRESTABELEC
                 FROM LOTEVENDA L, ADQUIRENTE A, RETFINANCADQ R, ESTABELECIMENTO E, PRODUTOADQ P 
                WHERE R.NRLOTEVENDA = L.NRLOTEVENDA 
                  AND R.NRADQUIRENTE = A.NRADQUIRENTE 
                  AND R.NRPRODUTOADQ = P.NRPRODUTOADQ 
                  AND R.NRESTABELEC = E.NRESTABELEC 
                  AND L.NRADQUIRENTE = A.NRADQUIRENTE 
                  AND TRUNC(R.DTCREDITO) BETWEEN :DTVENDAINI AND :DTVENDAFIN 
                  AND ((INSTR ( :P_NRPRODUTOADQ, TO_CHAR(P.NRPRODUTOADQ)) <> 0) OR ('T' = :P_TNRPRODUTOADQ)) 
                  AND ((INSTR ( :P_NRADQUIRENTE, TO_CHAR(A.NRADQUIRENTE)) <> 0) OR ('T' = :P_TNRADQUIRENTE)) 
                  AND ((INSTR ( :P_NRESTABELEC,  TO_CHAR(E.NRESTABELEC))  <> 0) OR ('T' = :P_TNRESTABELEC)) 
                  AND R.VRTAXAANT IS NOT NULL 
                  AND R.IDSTATUSVENDA = 'A' 
                  AND A.IDVISIVEL  = 'S' 
                  AND ( :TALL_FIELDS = 'T' OR (INSTR(DTCREDITO || '_' || NMESTABELEC || '_' || NMADQUIRENTE || '_' || CDLOTEVENDA || '_' || VRBRUTVENDA || '_' || VRLIQPGTO || '_' || VRTAXAANT, :ALL_FIELDS) <> 0) )
                GROUP BY TO_CHAR(R.DTCREDITO, 'dd/mm/yyyy'), E.CDESTABELEC, L.CDLOTEVENDA, E.NMESTABELEC, A.NMADQUIRENTE, R.VRTAXAANT, A.NRADQUIRENTE, E.NRESTABELEC
                ORDER BY 1,3,4,2";
            
            if(!empty($P_NRESTABELEC)) {
                $P_NRESTABELEC = implode('_', $P_NRESTABELEC);
            }
            
            if(!empty($P_NRADQUIRENTE)) {
                $P_NRADQUIRENTE = implode('_', $P_NRADQUIRENTE);
            }
            
            if(!empty($P_NRPRODUTOADQ)) {
                $P_NRPRODUTOADQ = implode('_', $P_NRPRODUTOADQ);
            }
            
            $parameters = array(
                ':P_NRADQUIRENTE'   => $P_NRADQUIRENTE,
                ':P_NRPRODUTOADQ'   => $P_NRPRODUTOADQ,
                ':P_NRESTABELEC'    => $P_NRESTABELEC,
                ':P_TNRADQUIRENTE'  => $P_TNRADQUIRENTE,
                ':P_TNRPRODUTOADQ'  => $P_TNRPRODUTOADQ,
                ':P_TNRESTABELEC'   => $P_TNRESTABELEC,
                ':DTVENDAINI'       => $dtlote[0],
                ':DTVENDAFIN'       => $dtlote[1],
                ':ALL_FIELDS'       => $conditions['ALL_FIELDS'],
                ':TALL_FIELDS'      => $conditions['TALL_FIELDS']
            );
            
            $vendascon = $this->vendaFactory->getAnticipatedSellsFiltered($parameters, $query);
            return $vendascon;
        } else{
            $parameters = array(
                ':P_NRADQUIRENTE'   => null,
                ':P_TNRADQUIRENTE'  => 'T',
                ':P_NRPRODUTOADQ'   => null,
                ':P_TNRPRODUTOADQ'  => 'T',
                ':P_NRESTABELEC'    => null,
                ':P_TNRESTABELEC'   => 'T',
                ':DTVENDAINI'       => $dtlote[0],
                ':DTVENDAFIN'       => $dtlote[1],
                ':ALL_FIELDS'       => $conditions['ALL_FIELDS'],
                ':TALL_FIELDS'      => $conditions['TALL_FIELDS']
            );
            
            $VendaConciliada = $this->vendaFactory->getAnticipatedSells($parameters);
            return $VendaConciliada;
        } 
    }

    public function loadAnticipatedSellsDetails($conditions) {
        $P_NRADQUIRENTE  = $conditions['NRADQUIRENTE'];
        $CDLOTEVENDA     = $conditions['CDLOTEVENDA'];
        $P_NRPRODUTOADQ  = $conditions['NRPRODUTOADQ'];
        $P_TNRPRODUTOADQ = null;
        $VRTAXAANT       = $conditions['VRTAXAANT'];
        $NRESTABELEC     = $conditions['NRESTABELEC'];
            
        if(empty($P_NRPRODUTOADQ)) {
            $P_NRPRODUTOADQ = null;
            $P_TNRPRODUTOADQ = 'T';
        }
        
        if(is_array($P_NRPRODUTOADQ)){
            $query = "SELECT TO_CHAR(S.DTVENDA, 'dd/mm/yy') as DTVENDA, S.CDNSU, C.CDCUPOM, S.VRBRUTVENDA, 
                  S.VRLIQPGTO, S.VRTAXAANTVENDA, S.VRTAXAADM, S.CDLOTEVENDA, S.NMADQUIRENTE, S.NMPRODUTOADQ
                  FROM (SELECT R.DTVENDA, R.CDNSU, R.VRBRUTVENDA, 
                    R.VRLIQPGTO, R.VRTAXAANTVENDA, R.VRTAXAADM, L.CDLOTEVENDA, A.NMADQUIRENTE, R.NRCONCLANC, P.NMPRODUTOADQ
                     FROM RETFINANCADQ R, PRODUTOADQ P, LOTEVENDA L, ADQUIRENTE A
                      WHERE R.NRLOTEVENDA = L.NRLOTEVENDA
                       AND R.NRADQUIRENTE    = A.NRADQUIRENTE
                       AND R.NRPRODUTOADQ    = P.NRPRODUTOADQ
                       AND ((INSTR (:P_NRPRODUTOADQ, '|' || TO_CHAR(P.NRPRODUTOADQ) ||'|' ) > 0) OR ('T' = :P_TNRPRODUTOADQ))
                       AND L.NRADQUIRENTE        = A.NRADQUIRENTE
                       AND A.NRADQUIRENTE    = :P_NRADQUIRENTE
                       AND L.CDLOTEVENDA     = :CDLOTEVENDA
                       AND R.VRTAXAANT = :VRTAXAANT
                       AND R.NRESTABELEC = :NRESTABELEC
                       AND P.NRPRODUTOADQ = R.NRPRODUTOADQ
                       AND L.IDTIPOLOTE = 'A')S 
                        LEFT JOIN CONSMOVCAIXA C
                         ON S.NRCONCLANC = C.NRCONCLANC
                         ORDER BY S.DTVENDA"; 
            if(is_array($P_NRPRODUTOADQ)){
                $paramsproduto = array(
                    ':P_NRPRODUTOADQ' => $P_NRPRODUTOADQ
                );
                foreach (array_keys($paramsproduto) as $index => $name) {
                    if(!empty($paramsproduto[$name])){
                        $query = $this->util->putArrayOnQuery($query, $name, $paramsproduto[$name]);
                        $paramsproduto[$name] = '';
                    }
                    else{
                        $paramsproduto[$name] = 'null';
                    }
                }
            } else {
                $paramsfilial = array(
                    ':P_NRPRODUTOADQ' => 'null'
                );
                 $query = preg_replace('/'.':P_NRPRODUTOADQ'.'/', $paramsfilial[':P_NRPRODUTOADQ'], $query, 4);
            }
            
            $parameters = array(
                ':P_NRADQUIRENTE'   => $P_NRADQUIRENTE,
                ':CDLOTEVENDA'      => $CDLOTEVENDA,
                ':P_TNRPRODUTOADQ'  => $P_TNRPRODUTOADQ,
                ':VRTAXAANT'        => $VRTAXAANT,
                ':NRESTABELEC'      => $NRESTABELEC
            );
            $vendascon = $this->vendaFactory->loadAnticipatedSellsDetailsFilter($parameters, $query);
            return $vendascon;
        }else{
            $parameters = array(
                ':P_NRADQUIRENTE'   => $P_NRADQUIRENTE,
                ':CDLOTEVENDA'      => $CDLOTEVENDA,
                ':P_NRPRODUTOADQ'   => $P_NRPRODUTOADQ,
                ':P_TNRPRODUTOADQ'  => $P_TNRPRODUTOADQ,
                ':VRTAXAANT'        => $VRTAXAANT,
                ':NRESTABELEC'      => $NRESTABELEC
            );
            $VendaConciliada = $this->vendaFactory->loadAnticipatedSellsDetails($parameters);
            return $VendaConciliada;
        }
    }
}