<?php 

namespace WebServiceCall\Service;

use WebServiceCall\Service\Interfaces\IConciliacao;

use WebServiceCall\Log\OutputStreamLogger;

use WebServiceCall\Repository\DB\Procedure\BeginConciliacaoCNC as BeginConciliacaoRepo;
use WebServiceCall\Repository\DB\Procedure\GeraFinanceiroCNC as GeraFinanceiroRepo;
use WebServiceCall\Repository\DB\AdquirenteSales as AquirenteSalesRepo;

class Conciliacao implements IConciliacao {
    private $estabelecimentos;
    private $dtIni;
    private $dtFim;
    
    private $beginConciliacaoRepo;
    private $geraFinanceiroRepo;
    
    public function __construct($dtIni, $dtFim) {
        $this->dtIni = $dtIni;
        $this->dtFim = $dtFim;

        $this->setBeginConcilicaoRepo(new BeginConciliacaoRepo());        
        $this->setGeraFinanceiroRepo(new GeraFinanceiroRepo());        
        $this->setAdquirenteSalesRepo(new AquirenteSalesRepo());        
    }
    
    private function setBeginConcilicaoRepo($beginConciliacaoRepo) {
        $this->beginConciliacaoRepo = $beginConciliacaoRepo;
    }

    private function setGeraFinanceiroRepo($geraFinanceiroRepo) {
        $this->geraFinanceiroRepo = $geraFinanceiroRepo;
    }
    
    private function setAdquirenteSalesRepo($adquirentesSalesRepo) {
        $this->adquirentesSalesRepo = $adquirentesSalesRepo;
    }
    
    // @Override
    public function isConciliacaoPerformed() {
        return $this->adquirentesSalesRepo->getQtdAdquirentesSales() !== 0;
    }
    
    // @Override
    public function performConciliacao($estabelecimentos) {
        OutputStreamLogger::log(PHP_EOL . "Realizando conciliação dos dados importados na base de dados:");
        
        $hasDataBeenConciliated = $this->conciliarDados($estabelecimentos);
        
        if($hasDataBeenConciliated) {
            OutputStreamLogger::log('A conciliação dos dados foi feita com sucesso.');
            $this->beginConciliacaoRepo->commit();
        } else {
            OutputStreamLogger::log('Ocorreu um erro ao tentar executar a rotina de conciliação.');
            $this->beginConciliacaoRepo->rollback();
        }
        
        OutputStreamLogger::log(PHP_EOL . "Realizando a geração do financeiro (REC e BCO)");
        
        $hasFinanceiroBeenGenerated = $this->gerarFinanceiro($estabelecimentos);
        
        if($hasFinanceiroBeenGenerated) {
            OutputStreamLogger::log('A geração de valores do Financeiro foi feita com sucesso.');
            $this->geraFinanceiroRepo->commit();
        } else { 
            OutputStreamLogger::log('Ocorreu um erro ao tentar gerar os valores do Financeiro.');
            $this->geraFinanceiroRepo->rollback();
        }
    }
    
    private function conciliarDados($estabelecimentos) {
        $conciliacoesResults = array_map(function($estabelec) {
            OutputStreamLogger::log('Conciliando dados para o estabelecimento: '. $estabelec);
            return  $this->beginConciliacaoRepo->beginConciliacaoCNC($estabelec, $this->dtIni, $this->dtFim);
        }, $estabelecimentos);
    
        $conciliacoesResult = array_reduce($conciliacoesResults, function($acc, $uniqueBool) {
            return $acc && $uniqueBool;
        }, true);
        
        return $conciliacoesResult;        
    }

    private function gerarFinanceiro($estabelecimentos) {
        $financeiroResults = array_map(function($estabelec) {
            OutputStreamLogger::log('Gerando financeiro para o estabelecimento: '. $estabelec);
            return  $this->geraFinanceiroRepo->geraFinanceiro($estabelec, $this->dtIni, $this->dtFim);
        }, $estabelecimentos);

        $financeiroResult = array_reduce($financeiroResults, function($acc, $uniqueBool) {
            return $acc && $uniqueBool;
        }, true);
        
        return $financeiroResult;
    }
}